## =============================================================================
## Requirements
## =============================================================================

library(gtsummary)

## =============================================================================
## Loop
## =============================================================================

bm_list<-list()

for (i in 1:length(outs)){
  ## Bivariate
  biv<-dta|>
    select(all_of(c("active_treat",vars,outs[i])))|>
    tbl_uvregression(data=_,
                     y=outs[i],
                     method=lm,
                     label = lab_sel(labels_all,vars)
    )  |> 
    add_global_p()|>
    bold_p() |>  
    bold_labels() |>
    italicize_levels()
  
  ## Multivariate
  mul<-dta |>
    select(all_of(c("active_treat",vars,outs[i])))|>
    lm(formula(paste(c(outs[i],"."),collapse="~")), 
       data = _) |> 
    tbl_regression(label = lab_sel(labels_all,vars)
    )|> 
    add_n() |>
    add_global_p() |>
    bold_p() |>  
    bold_labels() |>
    italicize_levels()
  
  ## Merge
  biv_mul<-tbl_merge(
    tbls = list(biv, mul), 
    tab_spanner = c("**Bivariate linear regression**", 
                    "**Multivariate linear regression**") 
  )
  
  bm_list[[i]]<-biv_mul
}

## =============================================================================
## Big merge
## =============================================================================

bm_16_tbl<-tbl_merge(
  tbls = bm_list, 
  tab_spanner = c("**One month follow up**", 
                  "**Six months follow up**") 
)